#[non_exhaustive]pub enum X509CertError {
InvalidSigningKey(String),
SubjectKeyError(Error),
InvalidHostname(Error),
CouldNotBuild(Arc<Error>),
CouldNotEncode(Error),
CouldNotFormatPkcs8(Error),
Bug(Bug),
}Expand description
An error that has occurred while trying to create a certificate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidSigningKey(String)
We received a signing key that we can’t use.
SubjectKeyError(Error)
We received a subject key that we can’t use.
InvalidHostname(Error)
We received a hostname that we couldn’t use: probably, it contained an equals sign or a comma.
CouldNotBuild(Arc<Error>)
We couldn’t construct the certificate.
CouldNotEncode(Error)
We constructed the certificate, but couldn’t encode it as DER.
CouldNotFormatPkcs8(Error)
We constructed a key but couldn’t format it as PKCS8.
Bug(Bug)
We’ve encountered some kind of a bug.