cert_validity

Function cert_validity 

pub(crate) fn cert_validity(
    now: SystemTime,
    lifetime_days: u32,
) -> Result<(Validity, SystemTime), X509CertError>
Return a Validity that includes now, and lasts for lifetime_days additionally.

Additionally, return the time at which the certificate expires.

We ensure that our cert is valid at least a day into the past.

We obfuscate our current time a little by rounding to the nearest midnight UTC.